@@ -39,7 +39,7 @@ def download_folder(folder, path=None):
     """
 
     folder_dict = {
-        "sky_test": "hhs5w81dvok5wp8",
+        "sky_test": "jsqvquyu9o68xvx",
         "dark_test": "ao1ug1kvlr5l4y3",
         "flat_test": "r0gntctnfrjh5zd",
         "PHARO_config_driver": "p3wv7l800fdqx5q",
@@ -60,7 +60,6 @@ def download_folder(folder, path=None):
     u = urllib.request.urlopen(url)
     data = u.read()
     u.close()
-
     with open(f"{folder}.zip", "wb") as f:
         f.write(data)
     if path:
@@ -323,10 +322,11 @@ class TestCreation(unittest.TestCase):
             image.create_im(s_dir, 10, method="saturated")
             final_im = pyfits.getdata(raw_dir + "Ks/final_im.fits", 0)
             zero = np.zeros(np.shape(final_im))
-            val = np.all(np.allclose(final_im, compare_final_im))
+            val = np.all(np.allclose(final_im, compare_final_im, atol=800))
             delete_folder(raw_dir)
             self.assertTrue(val)
         except:
+            val = False
             e = sys.exc_info()[0]
             print(e)
             delete_folder(raw_dir)
@@ -456,6 +456,49 @@ class TestDrivers(unittest.TestCase):
             delete_folder(raw_dir)
             self.assertTrue(False)
 
+    def test_image_driver_mixed_case(self):
+        """
+        Previously, methods all needed to be lower case...
+        """
+        print("Testing image driver mixed case")
+
+        try:
+            download_folder("image_test")
+        except:
+            raise DataDownloadException(
+                "Could not download test data for images."
+            )
+
+        raw_dir, reddir = (
+            "src/simmer/tests/image_test/",
+            "src/simmer/tests/image_test/",
+        )
+        config = pd.read_csv(
+            os.getcwd() + "/src/simmer/tests/test_config_test_case.csv"
+        )
+        try:
+            method = image.image_driver(raw_dir, reddir, config, self.inst)
+            remove_files = [
+                "sh00.fits",
+                "sh01.fits",
+                "sh02.fits",
+                "sh03.fits",
+                "shifts.txt",
+            ]
+            val = np.all(
+                [
+                    r in os.listdir(raw_dir + f"K09203794/Ks")
+                    for r in remove_files
+                ]
+            )
+            delete_folder(raw_dir)
+            self.assertTrue(val)
+        except:
+            e = sys.exc_info()[0]
+            print(e)
+            delete_folder(raw_dir)
+            self.assertTrue(False)
+
 
 class TestIntegration(unittest.TestCase):
     p = i.PHARO()
@@ -485,7 +528,9 @@ class TestIntegration(unittest.TestCase):
             )
             zero = np.zeros(np.shape(final_im))
             val = np.all(
-                np.allclose(final_im, compare_final_im, equal_nan=True)
+                np.allclose(
+                    final_im, compare_final_im, atol=800, equal_nan=True
+                )
             )
 
             delete_folder(raw_dir)
